@@ -113,6 +113,7 @@ class PlotItemBuilder(object):
                   major_style=None, minor_style=None):
         """
         Make `guiqwt.styles.GridParam` instance
+        
            * background = canvas background color
            * major_enabled = tuple (major_xenabled, major_yenabled)
            * minor_enabled = tuple (minor_xenabled, minor_yenabled)
@@ -145,6 +146,7 @@ class PlotItemBuilder(object):
              major_style=None, minor_style=None):
         """
         Make a grid `plot item` (`guiqwt.curve.GridItem` object)
+        
            * background = canvas background color
            * major_enabled = tuple (major_xenabled, major_yenabled)
            * minor_enabled = tuple (minor_xenabled, minor_yenabled)
@@ -192,9 +194,9 @@ class PlotItemBuilder(object):
                                          markeredgecolor) # MATLAB-style
             param.symbol.edgecolor = markeredgecolor
 
-    def __set_param(self, param, title, color, linestyle, linewidth,
-                    marker, markersize, markerfacecolor, markeredgecolor,
-                    shade, fitted, curvestyle, curvetype, baseline):
+    def __set_param(self, param, title, color, linestyle, linewidth, marker,
+                    markersize, markerfacecolor, markeredgecolor, shade,
+                    curvestyle, baseline):
         """Apply parameters to a `guiqwt.styles.CurveParam` instance"""
         self.__set_baseparam(param, color, linestyle, linewidth, marker,
                              markersize, markerfacecolor, markeredgecolor)
@@ -202,12 +204,8 @@ class PlotItemBuilder(object):
             param.label = title
         if shade is not None:
             param.shade = shade
-        if fitted is not None:
-            param.fitted = fitted
         if curvestyle is not None:
             param.curvestyle = curvestyle
-        if curvetype is not None:
-            param.curvetype = curvetype
         if baseline is not None:
             param.baseline = baseline
             
@@ -231,10 +229,11 @@ class PlotItemBuilder(object):
                 style = args[0]
             else:
                 x, y = get_x_y_from_data(args[0])
-                if isinstance(y, ndarray):
-                    style = next(self.style)
-                else:
+                y_matrix = not isinstance(y, ndarray)
+                if y_matrix:
                     style = [next(self.style) for yi in y]
+                else:
+                    style = next(self.style)
         elif len(args) == 2:
             a1, a2 = args
             if is_text_string(a2):
@@ -250,7 +249,7 @@ class PlotItemBuilder(object):
             raise TypeError("Wrong number of arguments")
         if isinstance(x, (list, tuple)):
             x = array(x)
-        if isinstance(y, (list, tuple)):
+        if isinstance(y, (list, tuple)) and not y_matrix:
             y = array(y)
         return x, y, style
         
@@ -293,7 +292,9 @@ class PlotItemBuilder(object):
         (may returns a list of curves if data contains more than one signal)
         (:py:class:`guiqwt.curve.CurveItem` object)
         
-        Example: mcurve(x, y, 'r+')
+        Example::
+            
+            mcurve(x, y, 'r+')
         """
         x, y, style = self.__get_arg_triple_plot(args)
         if isinstance(y, ndarray):
@@ -325,7 +326,9 @@ class PlotItemBuilder(object):
         based on a `guiqwt.styles.CurveParam` instance
         (:py:class:`guiqwt.curve.CurveItem` object)
         
-        Usage: pcurve(x, y, param)
+        Usage::
+            
+            pcurve(x, y, param)
         """
         curve = CurveItem(param)
         curve.set_data(x, y)
@@ -333,48 +336,39 @@ class PlotItemBuilder(object):
         self.__set_curve_axes(curve, xaxis, yaxis)
         return curve
 
-    def curve(self, x, y, title="",
-              color=None, linestyle=None, linewidth=None,
+    def curve(self, x, y, title="", color=None, linestyle=None, linewidth=None,
               marker=None, markersize=None, markerfacecolor=None,
-              markeredgecolor=None, shade=None, fitted=None,
-              curvestyle=None, curvetype=None, baseline=None,
+              markeredgecolor=None, shade=None, curvestyle=None, baseline=None,
               xaxis="bottom", yaxis="left"):
         """
         Make a curve `plot item` from x, y, data
         (:py:class:`guiqwt.curve.CurveItem` object)
+
             * x: 1D NumPy array
             * y: 1D NumPy array
             * color: curve color name
-            * linestyle: curve line style (MATLAB-like string or attribute name 
-              from the :py:class:`PyQt4.QtCore.Qt.PenStyle` enum
-              (i.e. "SolidLine" "DashLine", "DotLine", "DashDotLine", 
-              "DashDotDotLine" or "NoPen")
+            * linestyle: curve line style (MATLAB-like string or "SolidLine",
+              "DashLine", "DotLine", "DashDotLine", "DashDotDotLine", "NoPen")
             * linewidth: line width (pixels)
-            * marker: marker shape (MATLAB-like string or attribute name from 
-              the :py:class:`PyQt4.Qwt5.QwtSymbol.Style` enum (i.e. "Cross",
+            * marker: marker shape (MATLAB-like string or "Cross",
               "Ellipse", "Star1", "XCross", "Rect", "Diamond", "UTriangle", 
-              "DTriangle", "RTriangle", "LTriangle", "Star2" or "NoSymbol")
+              "DTriangle", "RTriangle", "LTriangle", "Star2", "NoSymbol")
             * markersize: marker size (pixels)
             * markerfacecolor: marker face color name
             * markeredgecolor: marker edge color name
             * shade: 0 <= float <= 1 (curve shade)
-            * fitted: boolean (fit curve to data)
-            * curvestyle: attribute name from the 
-              :py:class:`PyQt4.Qwt5.QwtPlotCurve.CurveStyle` enum
-              (i.e. "Lines", "Sticks", "Steps", "Dots" or "NoCurve")
-            * curvetype: attribute name from the 
-              :py:class:`PyQt4.Qwt5.QwtPlotCurve.CurveType` enum
-              (i.e. "Yfx" or "Xfy")
+            * curvestyle: "Lines", "Sticks", "Steps", "Dots", "NoCurve"
             * baseline (float: default=0.0): the baseline is needed for filling 
               the curve with a brush or the Sticks drawing style. 
-              The interpretation of the baseline depends on the curve type 
-              (horizontal line for "Yfx", vertical line for "Xfy")
             * xaxis, yaxis: X/Y axes bound to curve
         
-        Examples:
-        curve(x, y, marker='Ellipse', markerfacecolor='#ffffff')
-        which is equivalent to (MATLAB-style support):
-        curve(x, y, marker='o', markerfacecolor='w')
+        Example::
+            
+            curve(x, y, marker='Ellipse', markerfacecolor='#ffffff')
+
+        which is equivalent to (MATLAB-style support)::
+
+            curve(x, y, marker='o', markerfacecolor='w')
         """
         basename = _("Curve")
         param = CurveParam(title=basename, icon='curve.png')
@@ -383,8 +377,8 @@ class PlotItemBuilder(object):
             CURVE_COUNT += 1
             title = make_title(basename, CURVE_COUNT)
         self.__set_param(param, title, color, linestyle, linewidth, marker,
-                         markersize, markerfacecolor, markeredgecolor,
-                         shade, fitted, curvestyle, curvetype, baseline)
+                         markersize, markerfacecolor, markeredgecolor, shade,
+                         curvestyle, baseline)
         return self.pcurve(x, y, param, xaxis, yaxis)
 
     def merror(self, *args, **kwargs):
@@ -392,7 +386,9 @@ class PlotItemBuilder(object):
         Make an errorbar curve `plot item` based on MATLAB-like syntax
         (:py:class:`guiqwt.curve.ErrorBarCurveItem` object)
         
-        Example: mcurve(x, y, 'r+')
+        Example::
+            
+            mcurve(x, y, 'r+')
         """
         x, y, dx, dy, style = self.__get_arg_triple_errorbar(args)
         basename = _("Curve")
@@ -415,6 +411,7 @@ class PlotItemBuilder(object):
         Make an errorbar curve `plot item` 
         based on a `guiqwt.styles.ErrorBarParam` instance
         (:py:class:`guiqwt.curve.ErrorBarCurveItem` object)
+ 
             * x: 1D NumPy array
             * y: 1D NumPy array
             * dx: None, or scalar, or 1D NumPy array
@@ -423,7 +420,9 @@ class PlotItemBuilder(object):
             * errorbarparam: `guiqwt.styles.ErrorBarParam` object
             * xaxis, yaxis: X/Y axes bound to curve
         
-        Usage: perror(x, y, dx, dy, curveparam, errorbarparam)
+        Usage::
+            
+            perror(x, y, dx, dy, curveparam, errorbarparam)
         """
         curve = ErrorBarCurveItem(curveparam, errorbarparam)
         curve.set_data(x, y, dx, dy)
@@ -434,13 +433,13 @@ class PlotItemBuilder(object):
     def error(self, x, y, dx, dy, title="",
               color=None, linestyle=None, linewidth=None,
               errorbarwidth=None, errorbarcap=None, errorbarmode=None,
-              errorbaralpha=None, marker=None,
-              markersize=None, markerfacecolor=None, markeredgecolor=None,
-              shade=None, fitted=None, curvestyle=None, curvetype=None,
-              baseline=None, xaxis="bottom", yaxis="left"):
+              errorbaralpha=None, marker=None, markersize=None,
+              markerfacecolor=None, markeredgecolor=None, shade=None,
+              curvestyle=None, baseline=None, xaxis="bottom", yaxis="left"):
         """
         Make an errorbar curve `plot item` 
         (:py:class:`guiqwt.curve.ErrorBarCurveItem` object)
+
             * x: 1D NumPy array
             * y: 1D NumPy array
             * dx: None, or scalar, or 1D NumPy array
@@ -459,22 +458,19 @@ class PlotItemBuilder(object):
             * markerfacecolor: marker face color name
             * markeredgecolor: marker edge color name
             * shade: 0 <= float <= 1 (curve shade)
-            * fitted: boolean (fit curve to data)
             * curvestyle: attribute name from the 
               :py:class:`PyQt4.Qwt5.QwtPlotCurve.CurveStyle` enum
               (i.e. "Lines", "Sticks", "Steps", "Dots" or "NoCurve")
-            * curvetype: attribute name from the 
-              :py:class:`PyQt4.Qwt5.QwtPlotCurve.CurveType` enum
-              (i.e. "Yfx" or "Xfy")
             * baseline (float: default=0.0): the baseline is needed for filling 
               the curve with a brush or the Sticks drawing style. 
-              The interpretation of the baseline depends on the curve type 
-              (horizontal line for "Yfx", vertical line for "Xfy")
             * xaxis, yaxis: X/Y axes bound to curve
         
-        Examples::
+        Example::
+            
             error(x, y, None, dy, marker='Ellipse', markerfacecolor='#ffffff')
-            which is equivalent to (MATLAB-style support):
+        
+        which is equivalent to (MATLAB-style support)::
+
             error(x, y, None, dy, marker='o', markerfacecolor='w')
         """
         basename = _("Curve")
@@ -487,7 +483,7 @@ class PlotItemBuilder(object):
             curveparam.label = make_title(basename, CURVE_COUNT)
         self.__set_param(curveparam, title, color, linestyle, linewidth, marker,
                          markersize, markerfacecolor, markeredgecolor,
-                         shade, fitted, curvestyle, curvetype, baseline)
+                         shade, curvestyle, baseline)
         errorbarparam.color = curveparam.line.color
         if errorbarwidth is not None:
             errorbarparam.width = errorbarwidth
@@ -505,6 +501,7 @@ class PlotItemBuilder(object):
         """
         Make 1D Histogram `plot item` 
         (:py:class:`guiqwt.histogram.HistogramItem` object)
+
             * data (1D NumPy array)
             * bins: number of bins (int)
             * logscale: Y-axis scale (bool)
@@ -534,7 +531,9 @@ class PlotItemBuilder(object):
         based on a `guiqwt.styles.CurveParam` and 
         `guiqwt.styles.HistogramParam` instances
         
-        Usage: phistogram(data, curveparam, histparam)
+        Usage::
+            
+            phistogram(data, curveparam, histparam)
         """
         hist = HistogramItem(curveparam, histparam)
         hist.update_params()
@@ -717,7 +716,8 @@ class PlotItemBuilder(object):
         based on MATLAB-like syntax
         (:py:class:`guiqwt.image.QuadGridItem` object)
         
-        Examples:
+        Examples::
+
             pcolor(C)
             pcolor(X, Y, C)
         """
@@ -740,6 +740,7 @@ class PlotItemBuilder(object):
         Make a transformable image `plot item` (image with an arbitrary 
         affine transform)
         (:py:class:`guiqwt.image.TrImageItem` object)
+
             * data: 2D NumPy array (image pixel data)
             * filename: image filename (if data is not specified)
             * title: image title (optional)
@@ -770,8 +771,9 @@ class PlotItemBuilder(object):
         """
         Make an xyimage `plot item` (image with non-linear X/Y axes) from data
         (:py:class:`guiqwt.image.XYImageItem` object)
-            * x: 1D NumPy array
-            * y: 1D NumPy array
+
+            * x: 1D NumPy array (or tuple, list: will be converted to array)
+            * y: 1D NumPy array (or tuple, list: will be converted to array
             * data: 2D NumPy array (image pixel data)
             * title: image title (optional)
             * interpolation: 'nearest', 'linear' (default), 'antialiasing' (5x5)
@@ -781,6 +783,10 @@ class PlotItemBuilder(object):
                                background=background_color, colormap=colormap,
                                xformat=xformat, yformat=yformat,
                                zformat=zformat)
+        if isinstance(x, (list, tuple)):
+            x = array(x)
+        if isinstance(y, (list, tuple)):
+            y = array(y)
         image = XYImageItem(x, y, data, param)
         if eliminate_outliers is not None:
             image.set_lut_range(lut_range_threshold(image, 256,
@@ -792,6 +798,7 @@ class PlotItemBuilder(object):
         """
         Make a rectangular area image filter `plot item`
         (:py:class:`guiqwt.image.ImageFilterItem` object)
+
             * xmin, xmax, ymin, ymax: filter area bounds
             * imageitem: An imageitem instance
             * filter: function (x, y, data) --> data
@@ -811,6 +818,7 @@ class PlotItemBuilder(object):
         """
         Make a 2D Histogram `plot item` 
         (:py:class:`guiqwt.image.Histogram2DItem` object)
+
             * X: data (1D array)
             * Y: data (1D array)
             * NX: Number of bins along x-axis (int)
@@ -843,6 +851,7 @@ class PlotItemBuilder(object):
         """
         Make a label `plot item` 
         (:py:class:`guiqwt.label.LabelItem` object)
+
             * text: label text (string)
             * g: position in plot coordinates (tuple) 
               or relative position (string)
@@ -851,6 +860,7 @@ class PlotItemBuilder(object):
             * title: label name (optional)
         
         Examples::
+            
             make.label("Relative position", (x[0], y[0]), (10, 10), "BR")
             make.label("Absolute position", "R", (0,0), "R")
         """
@@ -880,6 +890,7 @@ class PlotItemBuilder(object):
         Make a legend `plot item` 
         (:py:class:`guiqwt.label.LegendBoxItem` or 
         :py:class:`guiqwt.label.SelectedLegendBoxItem` object)
+
             * anchor: legend position in relative position (string)
             * c (optional): position in canvas coordinates (tuple)
             * restrict_items (optional):
@@ -960,6 +971,7 @@ class PlotItemBuilder(object):
         """
         Make a marker `plot item`
         (:py:class:`guiqwt.shapes.Marker` object)
+
             * position: tuple (x, y)
             * label_cb: function with two arguments (x, y) returning a string
             * constraint_cb: function with two arguments (x, y) returning a 
@@ -974,10 +986,9 @@ class PlotItemBuilder(object):
               (i.e. "SolidLine" "DashLine", "DotLine", "DashDotLine", 
               "DashDotDotLine" or "NoPen")
             * linewidth: line width (pixels)
-            * marker: marker shape (MATLAB-like string or attribute name from 
-              the :py:class:`PyQt4.Qwt5.QwtSymbol.Style` enum (i.e. "Cross",
-              "Ellipse", "Star1", "XCross", "Rect", "Diamond", "UTriangle", 
-              "DTriangle", "RTriangle", "LTriangle", "Star2" or "NoSymbol")
+            * marker: marker shape (MATLAB-like string or "Cross", "Ellipse",
+              "Star1", "XCross", "Rect", "Diamond", "UTriangle", "DTriangle",
+              "RTriangle", "LTriangle", "Star2", "NoSymbol")
             * markersize: marker size (pixels)
             * markerfacecolor: marker face color name
             * markeredgecolor: marker edge color name
@@ -1022,6 +1033,7 @@ class PlotItemBuilder(object):
         """
         Make a rectangle shape `plot item` 
         (:py:class:`guiqwt.shapes.RectangleShape` object)
+
             * x0, y0, x1, y1: rectangle coordinates
             * title: label name (optional)
         """
@@ -1031,6 +1043,7 @@ class PlotItemBuilder(object):
         """
         Make an ellipse shape `plot item` 
         (:py:class:`guiqwt.shapes.EllipseShape` object)
+
             * x0, y0, x1, y1: ellipse x-axis coordinates
             * title: label name (optional)
         """
@@ -1044,6 +1057,7 @@ class PlotItemBuilder(object):
         """
         Make a circle shape `plot item` 
         (:py:class:`guiqwt.shapes.EllipseShape` object)
+
             * x0, y0, x1, y1: circle diameter coordinates
             * title: label name (optional)
         """
@@ -1053,6 +1067,7 @@ class PlotItemBuilder(object):
         """
         Make a segment shape `plot item` 
         (:py:class:`guiqwt.shapes.SegmentShape` object)
+
             * x0, y0, x1, y1: segment coordinates
             * title: label name (optional)
         """
@@ -1076,6 +1091,7 @@ class PlotItemBuilder(object):
         """
         Make an annotated rectangle `plot item` 
         (:py:class:`guiqwt.annotations.AnnotatedRectangle` object)
+
             * x0, y0, x1, y1: rectangle coordinates
             * title, subtitle: strings
         """
@@ -1087,6 +1103,7 @@ class PlotItemBuilder(object):
         """
         Make an annotated ellipse `plot item`
         (:py:class:`guiqwt.annotations.AnnotatedEllipse` object)
+
             * x0, y0, x1, y1: ellipse rectangle coordinates
             * ratio: ratio between y-axis and x-axis lengths
             * title, subtitle: strings
@@ -1101,6 +1118,7 @@ class PlotItemBuilder(object):
         """
         Make an annotated circle `plot item`
         (:py:class:`guiqwt.annotations.AnnotatedCircle` object)
+
             * x0, y0, x1, y1: circle diameter coordinates
             * title, subtitle: strings
         """
@@ -1110,6 +1128,7 @@ class PlotItemBuilder(object):
         """
         Make an annotated segment `plot item`
         (:py:class:`guiqwt.annotations.AnnotatedSegment` object)
+
             * x0, y0, x1, y1: segment coordinates
             * title, subtitle: strings
         """
@@ -1141,20 +1160,18 @@ class PlotItemBuilder(object):
                          function=None, title=None):
         """
         Make an info label `plot item` showing an XRangeSelection object infos
+        (:py:class:`guiqwt.label.DataInfoLabel` object)
+        (see example: :py:mod:`guiqwt.tests.computations`)
         
         Default function is `lambda x, dx: (x, dx)`.
 
-        Example:
-        -------
+        Example::
         
-        x = linspace(-10, 10, 10)
-        y = sin(sin(sin(x)))
-        range = make.range(-2, 2)
-        disp = make.range_info_label(range, 'BL', "x = %.1f ± %.1f cm",
-                                     lambda x, dx: (x, dx))
-        
-        (:py:class:`guiqwt.label.DataInfoLabel` object)
-        (see example: :py:mod:`guiqwt.tests.computations`)
+            x = linspace(-10, 10, 10)
+            y = sin(sin(sin(x)))
+            range = make.range(-2, 2)
+            disp = make.range_info_label(range, 'BL', "x = %.1f ± %.1f cm",
+                                         lambda x, dx: (x, dx))        
         """
         info = RangeInfo(label, range, function)
         return make.info_label(anchor, info, title=title)
