@@ -108,8 +108,7 @@ import numpy as np
 from guidata.qt.QtGui import (QMenu, QListWidget, QListWidgetItem, QVBoxLayout,
                               QToolBar, QMessageBox, QBrush, QColor, QPen,
                               QPolygonF)
-from guidata.qt.QtCore import (Qt, QPoint, QPointF, QLineF, SIGNAL, QRectF,
-                               QLine)
+from guidata.qt.QtCore import Qt, QPointF, QLineF, QRectF, Signal
 
 from guidata.utils import assert_interfaces_valid, update_dataset
 from guidata.configtools import get_icon, get_image_layout
@@ -127,8 +126,6 @@ from guiqwt.panels import PanelWidget, ID_ITEMLIST
 from guiqwt.baseplot import BasePlot, canvas_to_axes
 from guiqwt.styles import GridParam, CurveParam, ErrorBarParam, SymbolParam
 from guiqwt.shapes import Marker
-from guiqwt.signals import (SIG_ACTIVE_ITEM_CHANGED, SIG_ITEMS_CHANGED,
-                            SIG_AXIS_DIRECTION_CHANGED, SIG_PLOT_AXIS_CHANGED)
 
 def _simplify_poly(pts, off, scale, bounds):
     ax, bx, ay, by = scale
@@ -307,6 +304,9 @@ class GridItem(QwtPlotGrid):
 
     def update_params(self):
         self.gridparam.update_grid(self)
+        
+    def update_item_parameters(self):
+        self.gridparam.update_param(self)
 
     def get_item_parameters(self, itemparams):
         itemparams.add("GridParam", self, self.gridparam)
@@ -444,7 +444,12 @@ class CurveItem(QwtPlotCurve):
     def select(self):
         """Select item"""
         self.selected = True
+        plot = self.plot()
+        if plot is not None:
+            plot.blockSignals(True)
         self.setSymbol(SELECTED_SYMBOL)
+        if plot is not None:
+            plot.blockSignals(False)
         self.invalidate_plot()
     
     def unselect(self):
@@ -522,10 +527,9 @@ class CurveItem(QwtPlotCurve):
         ay = self.yAxis()
         xc = plot.transform(ax, x)
         yc = plot.transform(ay, y)
-        _distance, i, _inside, _other = self.hit_test(QPoint(xc, yc))
-        x = self.x(i)
-        y = self.y(i)
-        return x, y
+        _distance, i, _inside, _other = self.hit_test(QPointF(xc, yc))
+        point = self.sample(i)
+        return point.x(), point.y()
 
     def get_coordinates_label(self, xc, yc):
         title = self.title().text()
@@ -574,6 +578,9 @@ class CurveItem(QwtPlotCurve):
         if self.selected:
             self.select()
 
+    def update_item_parameters(self):
+        self.curveparam.update_param(self)
+
     def get_item_parameters(self, itemparams):
         itemparams.add("CurveParam", self, self.curveparam)
     
@@ -773,6 +780,9 @@ class PolygonMapItem(QwtPlotItem):
         if self.selected:
             self.select()
 
+    def update_item_parameters(self):
+        self.curveparam.update_param(self)
+
     def get_item_parameters(self, itemparams):
         itemparams.add("CurveParam", self, self.curveparam)
     
@@ -877,6 +887,7 @@ class ErrorBarCurveItem(CurveItem):
     def get_data(self):
         """
         Return error-bar curve data: x, y, dx, dy
+
             * x: NumPy array
             * y: NumPy array
             * dx: float or NumPy array (non-constant error bars)
@@ -887,6 +898,7 @@ class ErrorBarCurveItem(CurveItem):
     def set_data(self, x, y, dx=None, dy=None):
         """
         Set error-bar curve data:
+            
             * x: NumPy array
             * y: NumPy array
             * dx: float or NumPy array (non-constant error bars)
@@ -948,7 +960,7 @@ class ErrorBarCurveItem(CurveItem):
         ay = self.yAxis()
         xc = plot.transform(ax, x)
         yc = plot.transform(ay, y)
-        _distance, i, _inside, _other = self.hit_test(QPoint(xc, yc))
+        _distance, i, _inside, _other = self.hit_test(QPointF(xc, yc))
         x0, y0 = self.plot().canvas2plotitem(self, xc, yc)
         x = self.x(i)
         y = self.y(i)
@@ -1001,14 +1013,14 @@ class ErrorBarCurveItem(CurveItem):
             lines = []
             for i in RN:
                 yi = ty[i]
-                lines.append(QLine(txmin[i], yi, txmax[i], yi))
+                lines.append(QLineF(txmin[i], yi, txmax[i], yi))
             painter.drawLines(lines)
             if cap > 0:
                 lines = []
                 for i in RN:
                     yi = ty[i]
-                    lines.append(QLine(txmin[i], yi-cap, txmin[i], yi+cap))
-                    lines.append(QLine(txmax[i], yi-cap, txmax[i], yi+cap))
+                    lines.append(QLineF(txmin[i], yi-cap, txmin[i], yi+cap))
+                    lines.append(QLineF(txmax[i], yi-cap, txmax[i], yi+cap))
             painter.drawLines(lines)
             
         if self._dy is not None:
@@ -1019,15 +1031,15 @@ class ErrorBarCurveItem(CurveItem):
                 lines = []
                 for i in RN:
                     xi = tx[i]
-                    lines.append(QLine(xi, tymin[i], xi, tymax[i]))
+                    lines.append(QLineF(xi, tymin[i], xi, tymax[i]))
                 painter.drawLines(lines)
                 if cap > 0:
                     # Cap
                     lines = []
                     for i in RN:
                         xi = tx[i]
-                        lines.append(QLine(xi-cap, tymin[i], xi+cap, tymin[i]))
-                        lines.append(QLine(xi-cap, tymax[i], xi+cap, tymax[i]))
+                        lines.append(QLineF(xi-cap, tymin[i], xi+cap, tymin[i]))
+                        lines.append(QLineF(xi-cap, tymax[i], xi+cap, tymax[i]))
                 painter.drawLines(lines)
             else:
                 # Error area
@@ -1035,8 +1047,8 @@ class ErrorBarCurveItem(CurveItem):
                 rpoints = []
                 for i in RN:
                     xi = tx[i]
-                    points.append(QPoint(xi, tymin[i]))
-                    rpoints.append(QPoint(xi, tymax[i]))
+                    points.append(QPointF(xi, tymin[i]))
+                    rpoints.append(QPointF(xi, tymax[i]))
                 points += reversed(rpoints)
                 painter.setBrush(QBrush(self.errorBrush))
                 painter.drawPolygon(*points)
@@ -1050,6 +1062,10 @@ class ErrorBarCurveItem(CurveItem):
         self.errorbarparam.update_curve(self)
         CurveItem.update_params(self)
 
+    def update_item_parameters(self):
+        CurveItem.update_item_parameters(self)
+        self.errorbarparam.update_param(self)
+
     def get_item_parameters(self, itemparams):
         CurveItem.get_item_parameters(self, itemparams)
         itemparams.add("ErrorBarParam", self, self.errorbarparam)
@@ -1077,14 +1093,10 @@ class ItemListWidget(QListWidget):
         self.plot = None # the default plot...
         self.items = []
         
-        self.connect(self, SIGNAL('currentRowChanged(int)'),
-                     self.current_row_changed)
-        self.connect(self, SIGNAL('itemChanged(QListWidgetItem*)'),
-                     self.item_changed)
-        self.connect(self, SIGNAL('itemSelectionChanged()'),
-                     self.refresh_actions)
-        self.connect(self, SIGNAL('itemSelectionChanged()'),
-                     self.selection_changed)
+        self.currentRowChanged.connect(self.current_row_changed)
+        self.itemChanged.connect(self.item_changed)
+        self.itemSelectionChanged.connect(self.refresh_actions)
+        self.itemSelectionChanged.connect(self.selection_changed)
         
         self.setWordWrap(True)
         self.setMinimumWidth(140)
@@ -1100,8 +1112,8 @@ class ItemListWidget(QListWidget):
         self.manager = manager
 
         for plot in self.manager.get_plots():
-            self.connect(plot, SIG_ITEMS_CHANGED, self.items_changed)
-            self.connect(plot, SIG_ACTIVE_ITEM_CHANGED, self.items_changed)
+            plot.SIG_ITEMS_CHANGED.connect(self.items_changed)
+            plot.SIG_ACTIVE_ITEM_CHANGED.connect(self.items_changed)
         self.plot = self.manager.get_plot()
 
     def contextMenuEvent(self, event):
@@ -1135,8 +1147,12 @@ class ItemListWidget(QListWidget):
         
     def get_selected_items(self):
         """Return selected QwtPlot items
-        Warning: this is not the same as self.plot.get_selected_items
-        --> some items could appear in itemlist without being registered in 
+        
+        .. warning::
+
+            This is not the same as 
+            :py:data:`guiqwt.baseplot.BasePlot.get_selected_items`.
+            Some items could appear in itemlist without being registered in 
             plot widget items (in particular, some items could be selected in 
             itemlist without being selected in plot widget)
         """
@@ -1243,8 +1259,7 @@ class ItemListWidget(QListWidget):
         item = self.items[self.row(listwidgetitem)]
         visible = listwidgetitem.checkState() == Qt.Checked
         if visible != item.isVisible():
-            item.setVisible(visible)
-            self.plot.replot()
+            self.plot.set_item_visible(item, visible)
     
     def move_item(self, direction):
         """Move item to the background/foreground
@@ -1318,6 +1333,7 @@ class CurvePlot(BasePlot):
     """
     Construct a 2D curve plotting widget 
     (this class inherits :py:class:`guiqwt.baseplot.BasePlot`)
+    
         * parent: parent widget
         * title: plot title
         * xlabel: (bottom axis title, top axis title) or bottom axis title only
@@ -1326,10 +1342,14 @@ class CurvePlot(BasePlot):
         * yunit: (left axis unit, right axis unit) or left axis unit only
         * gridparam: GridParam instance
         * axes_synchronised: keep all x and y axes synchronised when zomming or
-                             panning
+          panning
     """
     DEFAULT_ITEM_TYPE = ICurveItemType
     AUTOSCALE_TYPES = (CurveItem, PolygonMapItem)
+    
+    #: Signal emitted by plot when plot axis has changed, e.g. when panning/zooming (arg: plot))
+    SIG_PLOT_AXIS_CHANGED = Signal("PyQt_PyObject")
+    
     def __init__(self, parent=None, title=None, xlabel=None, ylabel=None,
                  xunit=None, yunit=None, gridparam=None,
                  section="plot", axes_synchronised=False):
@@ -1347,7 +1367,7 @@ class CurvePlot(BasePlot):
         self.axes_synchronised = axes_synchronised
         
         # Installing our own event filter:
-        # (PyQwt's event filter does not fit our needs)
+        # (qwt's event filter does not fit our needs)
         self.canvas().installEventFilter(self.filter)
         self.canvas().setMouseTracking(True)
     
@@ -1407,8 +1427,8 @@ class CurvePlot(BasePlot):
     def set_marker_axes(self):
         curve = self.get_last_active_item(ITrackableItemType)
         if curve:
-            self.cross_marker.setAxis(curve.xAxis(), curve.yAxis())
-            self.curve_marker.setAxis(curve.xAxis(), curve.yAxis())
+            self.cross_marker.setAxes(curve.xAxis(), curve.yAxis())
+            self.curve_marker.setAxes(curve.xAxis(), curve.yAxis())
     
     def do_move_marker(self, event):
         pos = event.pos()
@@ -1471,7 +1491,7 @@ class CurvePlot(BasePlot):
         self.replot()
         # the signal MUST be emitted after replot, otherwise
         # we receiver won't see the new bounds (don't know why?)
-        self.emit(SIG_PLOT_AXIS_CHANGED, self)
+        self.SIG_PLOT_AXIS_CHANGED.emit(self)
 
     def do_zoom_view(self, dx, dy, lock_aspect_ratio=False):
         """
@@ -1520,7 +1540,7 @@ class CurvePlot(BasePlot):
         self.replot()
         # the signal MUST be emitted after replot, otherwise
         # we receiver won't see the new bounds (don't know why?)
-        self.emit(SIG_PLOT_AXIS_CHANGED, self)
+        self.SIG_PLOT_AXIS_CHANGED.emit(self)
         
     def do_zoom_rect_view(self, start, end):
         # XXX implement the case when axes are synchronised
@@ -1540,6 +1560,7 @@ class CurvePlot(BasePlot):
                 o1, o2 = o2, o1
             self.setAxisScale(k, o1, o2)
         self.replot()
+        self.SIG_PLOT_AXIS_CHANGED.emit(self)
 
     def get_default_item(self):
         """Return default item, depending on plot's default item type
@@ -1555,8 +1576,9 @@ class CurvePlot(BasePlot):
     def add_item(self, item, z=None):
         """
         Add a *plot item* instance to this *plot widget*
-            * item: QwtPlotItem (PyQt4.Qwt5) object implementing
-              the IBasePlotItem interface (guiqwt.interfaces)
+        
+            * item: :py:data:`qwt.QwtPlotItem` object implementing
+              the :py:data:`guiqwt.interfaces.IBasePlotItem` interface
             * z: item's z order (None -> z = max(self.get_items())+1)
         """
         if isinstance(item, QwtPlotCurve):
@@ -1575,7 +1597,7 @@ class CurvePlot(BasePlot):
         old_active = self.active_item
         BasePlot.set_active_item(self, item)
         if item is not None and old_active is not item:
-            self.grid.setAxis(item.xAxis(), item.yAxis())
+            self.grid.setAxes(item.xAxis(), item.yAxis())
 
     def get_plot_parameters(self, key, itemparams):
         if key == "grid":
@@ -1592,10 +1614,12 @@ class CurvePlot(BasePlot):
             self.grid.gridparam = dataset
         BasePlot.set_item_parameters(self, itemparams)
     
-    def do_autoscale(self, replot=True):
+    def do_autoscale(self, replot=True, axis_id=None):
         """Do autoscale on all axes"""
+        auto = self.autoReplot()
+        self.setAutoReplot(False)
         # XXX implement the case when axes are synchronised
-        for axis_id in self.AXIS_IDS:
+        for axis_id in self.AXIS_IDS if axis_id is None else [axis_id]:
             vmin, vmax = None, None
             if not self.axisEnabled(axis_id):
                 continue
@@ -1629,8 +1653,10 @@ class CurvePlot(BasePlot):
                 vmin = 10**(np.log10(vmin)-.002*dv)
                 vmax = 10**(np.log10(vmax)+.002*dv)
             self.set_axis_limits(axis_id, vmin, vmax)
+        self.setAutoReplot(auto)
         if replot:
             self.replot()
+        self.SIG_PLOT_AXIS_CHANGED.emit(self)
 
     def set_axis_limits(self, axis_id, vmin, vmax, stepsize=0):
         """Set axis limits (minimum and maximum values)"""
@@ -1645,6 +1671,7 @@ class CurvePlot(BasePlot):
     def get_axis_direction(self, axis_id):
         """
         Return axis direction of increasing values
+
             * axis_id: axis id (BasePlot.Y_LEFT, BasePlot.X_BOTTOM, ...)
               or string: 'bottom', 'left', 'top' or 'right'
         """
@@ -1654,6 +1681,7 @@ class CurvePlot(BasePlot):
     def set_axis_direction(self, axis_id, reverse=False):
         """
         Set axis direction of increasing values
+
             * axis_id: axis id (BasePlot.Y_LEFT, BasePlot.X_BOTTOM, ...)
               or string: 'bottom', 'left', 'top' or 'right'
             * reverse: False (default)
@@ -1670,12 +1698,13 @@ class CurvePlot(BasePlot):
             axis_map = self.canvasMap(axis_id)
             self.setAxisScale(axis_id, axis_map.s2(), axis_map.s1())
             self.updateAxes()
-            self.emit(SIG_AXIS_DIRECTION_CHANGED, self, axis_id)
+            self.SIG_AXIS_DIRECTION_CHANGED.emit(self, axis_id)
             
     def set_titles(self, title=None, xlabel=None, ylabel=None,
                    xunit=None, yunit=None):
         """
         Set plot and axes titles at once
+
             * title: plot title
             * xlabel: (bottom axis title, top axis title) 
               or bottom axis title only
@@ -1716,7 +1745,9 @@ class CurvePlot(BasePlot):
     def set_pointer(self, pointer_type):
         """
         Set pointer.
+
         Valid values of `pointer_type`:
+
             * None: disable pointer
             * "canvas": enable canvas pointer
             * "curve": enable on-curve pointer
@@ -1741,8 +1772,8 @@ class CurvePlot(BasePlot):
         self.set_axis_limits(yaxis, y0, y1)
         self.set_axis_limits(xaxis, x0, x1)     
         self.updateAxes()
-        self.emit(SIG_AXIS_DIRECTION_CHANGED, self, self.get_axis_id(yaxis))
-        self.emit(SIG_AXIS_DIRECTION_CHANGED, self, self.get_axis_id(xaxis))
+        self.SIG_AXIS_DIRECTION_CHANGED.emit(self, self.get_axis_id(yaxis))
+        self.SIG_AXIS_DIRECTION_CHANGED.emit(self, self.get_axis_id(xaxis))
         
     def set_plot_limits_synchronised(self, x0, x1, y0, y1):
         for yaxis, xaxis in (("left", "bottom"), ("right", "top")):
