@@ -124,7 +124,7 @@ from guiqwt.tools import (SelectTool, RectZoomTool, ColormapTool, HelpTool,
                           DisplayCoordsTool, AxisScaleTool, SaveAsTool,
                           AspectRatioTool, ContrastPanelTool, XCSPanelTool,
                           YCSPanelTool, SnapshotTool, DummySeparatorTool,
-                          CrossSectionTool, AverageCrossSectionTool,
+                          CrossSectionTool, AverageCrossSectionTool, AboutTool,
                           ImageStatsTool, ExportItemDataTool, EditItemDataTool,
                           ItemCenterTool, SignalStatsTool, CopyToClipboardTool)
 from guiqwt.interfaces import IPlotManager
@@ -576,6 +576,7 @@ class PlotManager(object):
         self.add_tool(CopyToClipboardTool)
         self.add_tool(PrintTool)
         self.add_tool(HelpTool)
+        self.add_tool(AboutTool)
         
     def register_all_curve_tools(self):
         """
@@ -826,7 +827,7 @@ class CurveWidgetMixin(PlotManager):
         """
         self.register_all_curve_tools()
 
-    def create_plot(self, options):
+    def create_plot(self, options, row=0, column=0, rowspan=1, columnspan=1):
         """
         Create the plotting widget (which is an instance of class 
         :py:class:`guiqwt.plot.BaseCurveWidget`), add it to the dialog box 
@@ -837,7 +838,8 @@ class CurveWidgetMixin(PlotManager):
         (:py:attr:`guiqwt.plot.CurveDialog.plot_layout`)
         """
         self.plot_widget = BaseCurveWidget(self, **options)
-        self.plot_layout.addWidget(self.plot_widget, 0, 0)
+        self.plot_layout.addWidget(self.plot_widget,
+                                   row, column, rowspan, columnspan)
         
         # Configuring plot manager
         self.add_plot(self.plot_widget.plot)
