@@ -78,7 +78,7 @@ import numpy as np
 from math import fabs, sqrt, sin, cos, pi
 
 from guidata.qt.QtGui import QPen, QBrush, QPolygonF, QTransform, QPainter
-from guidata.qt.QtCore import Qt, QRectF, QPointF, QPoint, QLineF
+from guidata.qt.QtCore import Qt, QRectF, QPointF, QLineF
 
 from guidata.utils import assert_interfaces_valid, update_dataset
 from guidata.py3compat import maxsize
@@ -89,8 +89,6 @@ from guiqwt.config import CONF, _
 from guiqwt.interfaces import IBasePlotItem, IShapeItemType, ISerializableType
 from guiqwt.styles import (MarkerParam, ShapeParam, RangeShapeParam,
                            AxesShapeParam, MARKERSTYLES)
-from guiqwt.signals import (SIG_RANGE_CHANGED, SIG_MARKER_CHANGED,
-                            SIG_AXES_CHANGED, SIG_ITEM_MOVED)
 from guiqwt.geometry import (vector_norm, vector_projection, vector_rotation,
                              compute_center)
 from guiqwt.baseplot import canvas_to_axes
@@ -189,6 +187,12 @@ class AbstractShape(QwtPlotItem):
                       will be considered as hit instead of self
         """
         pass
+
+    def update_item_parameters(self):
+        """
+        Update item parameters (dataset) from object properties
+        """
+        pass
     
     def get_item_parameters(self, itemparams):
         """
@@ -220,7 +224,7 @@ class AbstractShape(QwtPlotItem):
         new_pt = canvas_to_axes(self, new_pos)
         self.move_shape(old_pt, new_pt)
         if self.plot():
-            self.plot().emit(SIG_ITEM_MOVED, self, *(old_pt+new_pt))
+            self.plot().SIG_ITEM_MOVED.emit(self, *(old_pt+new_pt))
 
     def move_with_selection(self, delta_x, delta_y):
         """
@@ -388,13 +392,16 @@ class Marker(QwtPlotMarker):
             return sqrt((x-xc)**2), 0, False, None
         elif ms == "Cross":
             return sqrt(min((x-xc)**2, (y-yc)**2) ), 0, False, None
+
+    def update_item_parameters(self):
+        self.markerparam.update_param(self)
         
     def get_item_parameters(self, itemparams):
         """
         Appends datasets to the list of DataSets describing the parameters
         used to customize apearance of this item
         """
-        self.markerparam.update_param(self)
+        self.update_item_parameters()
         itemparams.add("MarkerParam", self, self.markerparam)
     
     def set_item_parameters(self, itemparams):
@@ -445,7 +452,7 @@ class Marker(QwtPlotMarker):
             x, y = self.constraint_cb(x, y)
         self.setValue(x, y)
         if self.plot():
-            self.plot().emit(SIG_MARKER_CHANGED, self)
+            self.plot().SIG_MARKER_CHANGED.emit(self)
             
     def get_pos(self):
         return self.xValue(), self.yValue()
@@ -664,8 +671,7 @@ class PolygonShape(AbstractShape):
         else:
             painter.drawPolyline(shape_points)
         if symbol != QwtSymbol.NoSymbol:
-            for i in range(points.size()):
-                symbol.draw(painter, points[i].toPoint())
+            symbol.drawSymbols(painter, points)
         if self.LINK_ADDITIONNAL_POINTS and other_points:
             pen2 = painter.pen()
             pen2.setStyle(Qt.DotLine)
@@ -723,8 +729,11 @@ class PolygonShape(AbstractShape):
         dy = new_pos[1]-old_pos[1]
         self.points += np.array([[dx, dy]])
 
-    def get_item_parameters(self, itemparams):
+    def update_item_parameters(self):
         self.shapeparam.update_param(self)
+
+    def get_item_parameters(self, itemparams):
+        self.update_item_parameters()
         itemparams.add("ShapeParam", self, self.shapeparam)
     
     def set_item_parameters(self, itemparams):
@@ -881,11 +890,14 @@ class ObliqueRectangleShape(PolygonShape):
     def set_rect(self, x0, y0, x1, y1, x2, y2, x3, y3):
         """
         Set the rectangle corners coordinates:
+            
             (x0, y0): top-left corner
             (x1, y1): top-right corner
             (x2, y2): bottom-right corner
             (x3, y3): bottom-left corner
             
+        ::
+            
             x: additionnal points (handles used for rotation -- other handles
             being used for rectangle resizing)
             
@@ -1100,7 +1112,7 @@ class EllipseShape(PolygonShape):
         painter.restore()
         if symbol != QwtSymbol.NoSymbol:
             for i in range(points.size()):
-                symbol.draw(painter, points[i].toPoint())
+                symbol.drawSymbol(painter, points[i].toPoint())
 
     def get_xline(self):
         return QLineF(*(tuple(self.points[0])+tuple(self.points[1])))
@@ -1253,13 +1265,13 @@ class Axes(PolygonShape):
             pp0 = p0
         self.set_rect(pp0, pp1, pp2)
         if self.plot():
-            self.plot().emit(SIG_AXES_CHANGED, self)
+            self.plot().SIG_AXES_CHANGED.emit(self)
             
     def move_shape(self, old_pos, new_pos):
         """Overriden to emit the axes_changed signal"""
         PolygonShape.move_shape(self, old_pos, new_pos)
         if self.plot():
-            self.plot().emit(SIG_AXES_CHANGED, self)
+            self.plot().SIG_AXES_CHANGED.emit(self)
 
     def draw(self, painter, xMap, yMap, canvasRect):
         PolygonShape.draw(self, painter, xMap, yMap, canvasRect)
@@ -1299,9 +1311,12 @@ class Axes(PolygonShape):
         poly.append(QPointF(a2x, a2y))
         painter.drawPolygon(poly)
         
+    def update_item_parameters(self):
+        self.axesparam.update_param(self)
+
     def get_item_parameters(self, itemparams):
         PolygonShape.get_item_parameters(self, itemparams)
-        self.axesparam.update_param(self)
+        self.update_item_parameters()
         itemparams.add("AxesShapeParam", self, self.axesparam)
     
     def set_item_parameters(self, itemparams):
@@ -1367,8 +1382,8 @@ class XRangeSelection(AbstractShape):
                          rct2.center().x(), rct2.bottom())
         painter.setPen(pen)
         x0, x1, y = self.get_handles_pos()        
-        sym.draw(painter, QPoint(x0, y))
-        sym.draw(painter, QPoint(x1, y))
+        sym.drawSymbol(painter, QPointF(x0, y))
+        sym.drawSymbol(painter, QPointF(x1, y))
         
     def hit_test(self, pos):
         x, _y = pos.x(), pos.y()
@@ -1399,7 +1414,7 @@ class XRangeSelection(AbstractShape):
             self._min += move
             self._max += move
 
-        self.plot().emit(SIG_RANGE_CHANGED, self, self._min, self._max)
+        self.plot().SIG_RANGE_CHANGED.emit(self, self._min, self._max)
         #self.plot().replot()
 
     def get_range(self):
@@ -1409,17 +1424,20 @@ class XRangeSelection(AbstractShape):
         self._min = _min
         self._max = _max
         if dosignal:
-            self.plot().emit(SIG_RANGE_CHANGED, self, self._min, self._max)
+            self.plot().SIG_RANGE_CHANGED.emit(self, self._min, self._max)
 
     def move_shape(self, old_pos, new_pos):
         dx = new_pos[0]-old_pos[0]
         self._min += dx
         self._max += dx
-        self.plot().emit(SIG_RANGE_CHANGED, self, self._min, self._max)
+        self.plot().SIG_RANGE_CHANGED.emit(self, self._min, self._max)
         self.plot().replot()
+
+    def update_item_parameters(self):
+        self.shapeparam.update_param(self)
         
     def get_item_parameters(self, itemparams):
-        self.shapeparam.update_param(self)
+        self.update_item_parameters()
         itemparams.add("ShapeParam", self, self.shapeparam)
     
     def set_item_parameters(self, itemparams):
