@@ -368,7 +368,7 @@ class InteractiveTool(GuiTool):
     SWITCH_TO_DEFAULT_TOOL = False # switch to default tool when finished
 
     #: Signal emitted by InteractiveTool when validating tool action
-    SIG_VALIDATE_TOOL = Signal()
+    SIG_VALIDATE_TOOL = Signal("PyQt_PyObject")
 
     #: Signal emitted by InteractiveTool when tool job is finished
     SIG_TOOL_JOB_FINISHED = Signal()
@@ -1829,8 +1829,8 @@ class AxisScaleTool(CommandTool):
 class HelpTool(CommandTool):
     def __init__(self, manager, toolbar_id=DefaultToolbarID):
         super(HelpTool, self).__init__(manager, _("Help"),
-                                      get_std_icon("DialogHelpButton", 16),
-                                      toolbar_id=toolbar_id)
+                                       get_std_icon("DialogHelpButton", 16),
+                                       toolbar_id=toolbar_id)
                                       
     def activate_command(self, plot, checked):
         """Activate tool"""
@@ -1845,6 +1845,18 @@ class HelpTool(CommandTool):
   - right-click + mouse move: zoom"""))
 
 
+class AboutTool(CommandTool):
+    def __init__(self, manager, toolbar_id=DefaultToolbarID):
+        super(AboutTool, self).__init__(manager, _("About")+" guiqwt",
+                                        get_icon("guiqwt.svg"),
+                                        toolbar_id=None)
+                                      
+    def activate_command(self, plot, checked):
+        """Activate tool"""
+        from guiqwt import about
+        QMessageBox.about(plot, _("About")+" guiqwt", about(html=True))
+
+
 class ItemManipulationBaseTool(CommandTool):
     TITLE = None
     ICON = None
